/*
 * A resource supporting the creation of user-specific opener resources.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsserver/file_paging.h>
#include <fsserver/filesystem_interface.h>
#include <fsserver/resource.h>



/* Support for providing access to user-specific filesystems. */

class FilesystemResource : public Resource, public FilePaging, public Filesystem
{
public:
    explicit FilesystemResource(Pages *pages);

    /* Server details. */

    int expected_items();

    ipc_server_handler_type handler();

    void *interface()
    { return static_cast<Filesystem *>(this); }

    /* Filesystem interface methods. */

    virtual long open_for_user(sys_uid_t uid, sys_gid_t gid, sys_mode_t umask,
                               l4_cap_idx_t *opener) = 0;
};

// vim: tabstop=4 expandtab shiftwidth=4
